@@ -57,6 +57,10 @@ except Exception:
 
 
 class ModelResults:
+    """
+    Evaluate model performance & explore output
+    """
+
     def _jaccard_similarity(self, topic_1, topic_2):
         """
         Derives the Jaccard similarity of two topics
@@ -703,6 +707,27 @@ class ModelResults:
                 print(f"Model: {trained_model}", file=f)
                 print("\n", file=f)
 
+                print("Overall scores:", file=f)
+                print("\n", file=f)
+                print(
+                    tabulate(
+                        temp_df[
+                            [
+                                "precision",
+                                "recall",
+                                "accuracy",
+                                "f1",
+                            ]
+                        ],
+                        headers="keys",
+                        tablefmt="pipe",
+                        numalign="left",
+                        showindex=False,
+                    ),
+                    file=f,
+                )
+                print("\n", file=f)
+
                 # Precision / recall / f1-score for each predicted class
                 report_df = (
                     pd.DataFrame(
@@ -785,6 +810,27 @@ class ModelResults:
                 print(f"Model: {trained_model}", file=f)
                 print("\n", file=f)
 
+                print("Overall scores:", file=f)
+                print("\n", file=f)
+                print(
+                    tabulate(
+                        temp_df[
+                            [
+                                "precision",
+                                "recall",
+                                "accuracy",
+                                "f1",
+                            ]
+                        ],
+                        headers="keys",
+                        tablefmt="pipe",
+                        numalign="left",
+                        showindex=False,
+                    ),
+                    file=f,
+                )
+                print("\n", file=f)
+
                 crosstab = pd.crosstab(
                     np.array(y_test),
                     y_predicted,
