@@ -7,6 +7,10 @@ from pythonjsonlogger import jsonlogger
 
 
 class SetupMethods:
+    """
+    Set up coding environment
+    """
+
     def setup_logger(self):
         """
         Returns
